summaryrefslogtreecommitdiffstats
path: root/4a-hal-utilities/4a-hal-utilities-alsa-data.c
diff options
context:
space:
mode:
authorJonathan Aillet <jonathan.aillet@iot.bzh>2019-04-18 12:40:25 +0200
committerJonathan Aillet <jonathan.aillet@iot.bzh>2019-05-24 12:05:52 +0200
commit68138a3ec7a78ad7304d291ff92d8e5292847c4e (patch)
tree9157134d50a749c838afdf93a49c4ce17a018347 /4a-hal-utilities/4a-hal-utilities-alsa-data.c
parent196e723e79a1f5eae41cf4a8b1450df0679a4af8 (diff)
Clarify internals hal functions and files names
The purpose of this commit is to have of a more standard way to name files and functions used to generate/handle hal api (generated from hal json configuration file). It occurred to me that 'hal-controller' was not a good name because it is harder for people who don't know about the app-controller to understanded what is the purpose of these files/functions. It was renamed to 'internal-hal' because it's about hal that are all handle/load by hal-manager in opposition of external-hal that are independant binding/binder that can register themselves to hal-manager. BUG-AGL: SPEC-2329 Change-Id: I11b7efe64ec474b004a2a15ed8969b9db95d428f Signed-off-by: Jonathan Aillet <jonathan.aillet@iot.bzh>
Diffstat (limited to '4a-hal-utilities/4a-hal-utilities-alsa-data.c')
-rw-r--r--4a-hal-utilities/4a-hal-utilities-alsa-data.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/4a-hal-utilities/4a-hal-utilities-alsa-data.c b/4a-hal-utilities/4a-hal-utilities-alsa-data.c
index 79cc8eb..6409253 100644
--- a/4a-hal-utilities/4a-hal-utilities-alsa-data.c
+++ b/4a-hal-utilities/4a-hal-utilities-alsa-data.c
@@ -24,10 +24,10 @@
#include "4a-hal-utilities-alsa-data.h"
/*******************************************************************************
* Free contents of 'CtlHalAlsaMapT' data structure *
******************************************************************************/
-uint8_t HalUtlFreeAlsaCtlsMap(struct CtlHalAlsaMapT *alsaCtlsMap)
+uint8_t HalUtlFreeAlsaCtlsMap(struct InternalHalAlsaMapT *alsaCtlsMap)
{
int idx;
@@ -24,10 +24,10 @@
#include "4a-hal-utilities-alsa-data.h"
/*******************************************************************************
- * Free contents of 'CtlHalAlsaMapT' data structure *
+ * Free contents of 'InternalHalAlsaMapT' data structure *
******************************************************************************/